![Logo](/Logo.png)

# License
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)  
This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details

# Setup

**1. Clone the repo and use the install script.**

Clone the repo.
```
git clone https://github.com/elijahsawyers/autostack.git
```

Navigate to the project directory, and run the install bash script.
```
cd /path/to/project/
chmod +x install.sh
./install.sh 
```

**2. Or just use pip to install.**

```
pip3 install autostack
```

# Usage 

In one terminal window, execute the autostack command to listen for errors.
```
autostack
```

In another terminal window, execute autostack-termal which will inform the autostack listener to listen for errors in the terminal.
```
autostack-terminal
``` 

# Authors
* [Elijah Sawyers](https://github.com/elijahsawyers)
* [Benjamin Sanders](https://github.com/BenOSanders)
* [Caleb Werth](https://github.com/cwerth1)
